//+------------------------------------------------------------------+
//|                                                         file.mqh |
//|                                      Copyright  2016, Marketeer |
//|                          https://www.mql5.com/en/users/marketeer |
//|           MQL's OOP notes: Managing resources by object wrappers |
//|                        https://www.mql5.com/en/blogs/post/680571 |
//+------------------------------------------------------------------+

class File
{
  private:
    int file;
  
  public:
    File(const string name, const int flags, const short delimiter)
    {
      file = FileOpen(name, flags, delimiter);
    }

    File(const string name, const int flags)
    {
      file = FileOpen(name, flags);
    }
    
    bool isOpened() const
    {
      return (file != INVALID_HANDLE);
    }
    
    bool operator!() const
    {
      return !isOpened();
    }
    
    int handle() const
    {
      return file;
    }
    
    virtual ~File()
    {
      if(file != INVALID_HANDLE)
      {
        Print("File is closed automatically");
        FileClose(file);
      }
    }
};

// USAGE
/*

void processFile(const string inputFileName)
{
  File f(inputFileName, FILE_READ | FILE_TXT | FILE_SHARE_READ, ',');
  if(f)
  {
    int handle = f.handle();
    
    string line = FileReadString(handle);
    
    if(line == "") return;
    
    string line2 = FileReadString(handle);
    
    if(line2 == "") return;
    
    // ...
  }
  
  // no FileClose call is required at any exit point
}

*/